@@ -3,6 +3,7 @@
 import json
 import os
 import shutil
+import socket
 import tempfile
 import threading
 from contextlib import contextmanager
@@ -208,6 +209,22 @@ def test_add_response_header(driver, httpbin):
     assert 'Herman Melville' not in driver.page_source
 
 
+def test_interceptor_does_not_modify_body(driver, httpbin):
+    """There should be no change to the size of the response body if a
+    response interceptor does not modify it. Originally the cause of #375.
+    """
+    size = 0
+
+    def interceptor(req, res):
+        nonlocal size
+        size = len(res.body)
+
+    driver.response_interceptor = interceptor
+    driver.get(f'{httpbin}/html')
+
+    assert size and len(driver.last_request.response.body) == size
+
+
 def test_add_request_parameter(driver, httpbin):
     def interceptor(req):
         params = req.params
@@ -517,3 +534,28 @@ def test_switch_proxy_on_the_fly(driver_path, chrome_options, httpbin, httpproxy
             driver.get(f'{httpbin}/html')
 
             assert 'This passed through a authenticated http proxy' in driver.page_source
+
+
+def test_har_encoded_brotli_response(driver_path, chrome_options, httpbin):
+    with create_driver(driver_path, chrome_options, {'enable_har': True}) as driver:
+        driver.get(f'{httpbin}/brotli')
+
+        har = json.loads(driver.har)
+
+        assert len(har['log']['entries']) == 1
+        assert har['log']['entries'][0]['request']['url'] == f'{httpbin}/brotli'
+        assert har['log']['entries'][0]['response']['status'] == 200
+
+
+def test_socket_timeout(driver, httpbin):
+    """Setting a timeout on the socket puts the socket into non-blocking mode.
+    This causes OpenSSL's handshake mechanism to raise an EWOULDBLOCK error,
+    which in turn causes the request to fail.
+
+    Selenium Wire has been modified to handle this error and retry the handshake
+    operation - so we expect the request to succeed.
+    """
+    socket.setdefaulttimeout(60)
+    driver.get(f'{httpbin}/html')
+
+    assert driver.requests
